Credits
=======

Sark is written and maintained by Tamir Bahar.

Contributors
------------

The following people have contributed directly or indirectly to this project:

- `darx0r <https://github.com/darx0r>`_
- `iamtimmy <https://github.com/iamtimmy>`_
- `ynvb <https://github.com/ynvb>`_
- `OfficialMan <https://github.com/OfficialMan>`_

Please add yourself here alphabetically when you submit your first pull request.